# scans2any

192.168.56.10 |  | windows
--- | --- | ---
53/tcp | dns |
53/udp | dns |
80/tcp | www | Microsoft-IIS/10.0
88/tcp | kerberos? |
123/udp | ntp |
135/tcp | epmap |
137/udp | netbios-ns |
139/tcp | smb |
389/tcp | ldap |
445/tcp | cifs |
464/tcp | kpasswd? |
593/tcp | http-rpc-epmap |
636/tcp | ldap |
3268/tcp | ldap |
3269/tcp | ldap |
3389/tcp | msrdp |
5355/udp | llmnr |
5985/tcp | www | Microsoft-HTTPAPI/2.0
5986/tcp | www | Microsoft-HTTPAPI/2.0
9389/tcp |  |
47001/tcp | www | Microsoft-HTTPAPI/2.0
49664/tcp | dce-rpc |
49665/tcp | dce-rpc |
49666/tcp | dce-rpc |
49667/tcp | dce-rpc |
49669/tcp | ncacn_http |
49670/tcp | dce-rpc |
49672/tcp | dce-rpc |
49675/tcp | dce-rpc |
49685/tcp | dce-rpc |
49785/tcp | dce-rpc |
49863/tcp | dce-rpc |
49966/tcp | dce-rpc |

192.168.56.11 |  | windows
--- | --- | ---
53/tcp | dns |
53/udp | dns |
88/tcp | kerberos? |
123/udp | ntp |
135/tcp | epmap |
137/udp | netbios-ns |
139/tcp | smb |
389/tcp | ldap |
445/tcp | cifs |
464/tcp | kpasswd? |
593/tcp | http-rpc-epmap |
636/tcp | ldap |
3268/tcp | ldap |
3269/tcp | ldap |
3389/tcp | msrdp |
5355/udp | llmnr |
5985/tcp | www | Microsoft-HTTPAPI/2.0
5986/tcp | www | Microsoft-HTTPAPI/2.0
9389/tcp |  |
47001/tcp | www | Microsoft-HTTPAPI/2.0
49664/tcp | dce-rpc |
49665/tcp | dce-rpc |
49666/tcp | dce-rpc |
49667/tcp | dce-rpc |
49669/tcp | dce-rpc |
49670/tcp | ncacn_http |
49673/tcp | dce-rpc |
49676/tcp | dce-rpc |
49722/tcp | dce-rpc |
65363/tcp | dce-rpc |
65464/tcp | dce-rpc |

192.168.56.22 |  | windows
--- | --- | ---
80/tcp | www | Microsoft-IIS/10.0
135/tcp | epmap |
137/udp | netbios-ns |
139/tcp | smb |
445/tcp | cifs |
1433/tcp | mssql |
3389/tcp | msrdp |
5355/udp | llmnr |
5985/tcp | www | Microsoft-HTTPAPI/2.0
5986/tcp | www | Microsoft-HTTPAPI/2.0
47001/tcp | www | Microsoft-HTTPAPI/2.0
49664/tcp | dce-rpc |
49665/tcp | dce-rpc |
49666/tcp | dce-rpc |
49667/tcp | dce-rpc |
49668/tcp | dce-rpc |
49669/tcp | dce-rpc |
49682/tcp | dce-rpc |
49734/tcp | dce-rpc |
49813/tcp | sybase |